@@ -5,7 +5,7 @@ use Email::Simple;
 use Email::FolderType qw/folder_type/;
 
 use vars qw($VERSION);
-$VERSION = "0.8";
+$VERSION = "0.82";
 
 =head1 NAME
 
@@ -17,7 +17,7 @@ Email::Folder - read all the messages from a folder as Email::Simple objects.
 
  my $folder = Email::Folder->new("some_file");
 
- print join "\n", map { $_->header("Subject") }, $folder->messages;
+ print join "\n", map { $_->header("Subject") } $folder->messages;
 
 =head1 METHODS
 
@@ -25,6 +25,9 @@ Email::Folder - read all the messages from a folder as Email::Simple objects.
 
 Takes the name of a folder, and a hash of options
 
+If a 'reader' option is passed in then that is
+used as the class to read in messages with.
+
 =cut
 
 sub new {
@@ -32,7 +35,13 @@ sub new {
     my $folder = shift || carp "Must provide a folder name\n";
     my %self = @_;
 
-    my $reader = "Email::Folder::".folder_type($folder);
+    my $reader;
+
+    if ($self{reader}) {
+        $reader = $self{reader};
+    } else {
+        $reader = "Email::Folder::".folder_type($folder);
+    }
     eval "require $reader" or die $@;
 
     $self{_folder} = $reader->new($folder, @_);
@@ -40,7 +49,6 @@ sub new {
     return bless \%self, $class;
 }
 
-
 =head2 messages
 
 Returns a list containing all of the messages in the folder.  Can only
@@ -100,6 +108,17 @@ sub bless_message {
 }
 
 
+=head2 reader
+
+read-only accessor to the underlying Email::Reader subclass instance
+
+=cut
+
+sub reader {
+    my $self = shift;
+    return $self->{_folder};
+}
+
 1;
 
 __END__
